summaryrefslogtreecommitdiff
path: root/extra/scripts/gen_bits_syscall_h.sh
diff options
context:
space:
mode:
authorMiles Bader <miles@lsi.nec.co.jp>2002-09-05 05:29:49 +0000
committerMiles Bader <miles@lsi.nec.co.jp>2002-09-05 05:29:49 +0000
commite72144d6265637d1e34bd79f5e373b4ff98d4d29 (patch)
treec9cda2a39e645575df372fe90840cc1176f6055b /extra/scripts/gen_bits_syscall_h.sh
parenta9b6db9b78d8c63eafde91be08f12c6fa0ba1311 (diff)
Change <bits/syscall.h> to <bits/sysnum.h>.
Diffstat (limited to 'extra/scripts/gen_bits_syscall_h.sh')
-rwxr-xr-xextra/scripts/gen_bits_syscall_h.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/extra/scripts/gen_bits_syscall_h.sh b/extra/scripts/gen_bits_syscall_h.sh
index df83bcef1..4c634e7db 100755
--- a/extra/scripts/gen_bits_syscall_h.sh
+++ b/extra/scripts/gen_bits_syscall_h.sh
@@ -3,7 +3,7 @@
# June 27, 2001 Manuel Novoa III
#
# This script expects TOPDIR and CC (as used in the Makefiles) to be set in
# the environment, and outputs the appropriate $TOPDIR/include/bits/syscall.h
# corresponding to $TOPDIR/include/asm/unistd.h to stdout.
#
# Warning!!! This does _no_ error checking!!!
@@ -16,10 +16,10 @@ UNISTD_H_PATH=$TOPDIR/include/asm/unistd.h
) |
$CC -E - |
( echo "/* WARNING!!! AUTO-GENERATED FILE!!! DO NOT EDIT!!! */" ; echo ;
- echo "#ifndef _BITS_SYSCALL_H" ;
- echo "#define _BITS_SYSCALL_H" ;
+ echo "#ifndef _BITS_SYSNUM_H" ;
+ echo "#define _BITS_SYSNUM_H" ;
echo "#ifndef _SYSCALL_H" ;
- echo "# error \"Never use <bits/syscall.h> directly; include <sys/syscall.h> instead.\"" ;
+ echo "# error \"Never use <bits/sysnum.h> directly; include <sys/syscall.h> instead.\"" ;
echo "#endif" ; echo ;
sed -ne 's/^UCLIBC_\([A-Za-z0-9_]*\) *\(.*\)/#undef __NR_\1\
#define __NR_\1 \2\
@@ -3,7 +3,7 @@
#
# This script expects TOPDIR and CC (as used in the Makefiles) to be set in
-# the environment, and outputs the appropriate $TOPDIR/include/bits/syscall.h
+# the environment, and outputs the appropriate $TOPDIR/include/bits/sysnum.h
# corresponding to $TOPDIR/include/asm/unistd.h to stdout.
#